<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 07/02/2011 *
 * ===================                          Last change: 07/02/2011 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : order_filter.php                                 *
 * -------------------------------------------------------------------- *
 * Short description : Filters for ext-order                            *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Filter fuer ext-order                            *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2012 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Filter for returning given user's points
function FILTER_USER_POINTS ($filterData) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called!');

	// Get the points and add them to the existing
	$filterData['points'] += countSumTotalData($filterData['userid'], 'user_points', 'points');

	// Return the data for next filter
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done!');
	return $filterData;
}

// Filter for returning given user's locked points
function FILTER_LOCKED_USER_POINTS ($filterData) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called!');

	// Get the points and add them to the existing
	$filterData['points'] += countSumTotalData($filterData['userid'], 'user_points', 'locked_points');

	// Return the data for next filter
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done!');
	return $filterData;
}

// Filter for returning all user points column names
function FILTER_GET_ALL_USER_POINTS_COLUMN_NAMES ($filterData) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called!');
	// Add 'points' and 'locked_points'
	$filterData['columns'] .= $filterData['alias'] . 'points' . $filterData['separator'] . $filterData['alias'] . 'locked_points' . $filterData['separator'];

	// Return the data for next filter
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done!');
	return $filterData;
}

// Filter for excluding tester users in WHERE statements
function FILTER_TESTER_USER_EXCLUSION_SQL ($sql) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called! - sql(' . strlen($sql) . ')=' . $sql);

	/*
	 * Allow testers to be included? Do only this when you only want to test
	 * it, normally you don't want these accounts being included everywhere.
	 */
	if (ifTesterAccountsAllowed()) {
		// Do not exclude tester accounts
		return $sql;
	} // END - if

	// Add it, as of this filter is registered only with ext-user >= 0.5.0
	if (empty($sql)) {
		// Add WHERE
		$sql = " WHERE `surname` NOT LIKE '{?tester_user_surname_prefix?}%%'";
	} else {
		// Add AND
		$sql .= " AND `surname` NOT LIKE '{?tester_user_surname_prefix?}%%'";
	}

	// Return the data for next filter
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done! - sql(' . strlen($sql) . ')=' . $sql);
	return $sql;
}

// Filter for including tester users in WHERE statements
function FILTER_TESTER_USER_INCLUSION_SQL ($sql) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called! - sql(' . strlen($sql) . ')=' . $sql);
	// Add it, as of this filter is registered only with ext-user >= 0.5.0
	if (empty($sql)) {
		// Add WHERE
		$sql = " WHERE `surname` LIKE '{?tester_user_surname_prefix?}%%'";
	} else {
		// Add AND
		$sql .= " AND `surname` LIKE '{?tester_user_surname_prefix?}%%'";
	}

	// Return the data for next filter
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done! - sql(' . strlen($sql) . ')=' . $sql);
	return $sql;
}

// Filter to add SQL columns to user registration
function FILTER_TESTER_USER_REGISTRATION_ADD_SQL_COLUMNS ($filterData) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called!');

	// Does the admin create a tester account?
	if ((isAdmin()) && (isTesterUserName(postRequestElement('surname')))) {
		// Yes, these accounts never needs confirmation (you can still test it by creating a usual account).
		setPostRequestElement('status', 'CONFIRMED');
	} // END - if

	// Return filter data
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done!');
	//* NOISY-DEBUG: */ print __FUNCTION__.':filterData=<pre>'.print_r($filterData,true).'</pre>';
	return $filterData;
}

// Filter to add 'converting' SQL statements
function FILTER_ADD_USER_DATA_CONVERT_SQL_COLUMNS ($sql) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called! - sql(' . strlen($sql) . ')=' . $sql);

	// Add it
	$sql .= ', UNIX_TIMESTAMP(`lock_timestamp`) AS `lock_timestamp`';

	// Return the data for next filter
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done! - sql(' . strlen($sql) . ')=' . $sql);
	return $sql;
}

// Filter for handling user subids (called by referral link)
function FILTER_HANDLE_USER_SUBID ($filterData) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called!');

	// Return filter data
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done!');
	//* NOISY-DEBUG: */ print __FUNCTION__.':filterData=<pre>'.print_r($filterData,true).'</pre>';
	return $filterData;
}

// Filter for adding SQL columns on user registration for subid
function FILTER_SUBID_USER_REGISTRATION_ADD_SQL_COLUMNS ($filterData) {
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called!');

	// Is the sub id set in session?
	if (isSessionVariableSet('subid')) {
		// Okay, add subid here
		addExtraRegistrationColumns(', `subid`');
		addExtraRegistrationData(", '" . getSession('subid') . "'");
	} // END - if

	// Return filter data
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done!');
	return $filterData;
}

// [EOF]
?>
